{% extends "templates/base.jinja2" %}

{% block container %}
    <h1 class="view">Storage <small>list</small></h1>
    <h2>By name</h2>
    <table class="table table-striped table-bordered datatables">
        <thead>
            <tr>
                <th>Name</th>
                <th>Volumes</th>
                <th>Total backups</th>
            </tr>
        </thead>
        <tbody>
            {% for storage in objects %}
                <tr class="clickable-row" data-link="{{ request.route_url('storage_detail', id=storage.Storage.storageid) }}">
                    <td>{{ macros.link(storage.Storage.render_name(request)) }}</td>
                    <td>{{ storage.num_volumes }}</td>
                    <td>{{ storage.Storage.format_byte_size(storage.total_backup_size) }}</td>
                </tr>
            {% endfor %}
        </tbody>
    </table>
{% endblock %}
