{% extends "templates/base.jinja2" %}

{% block content %}
    <div class="span12">
        <h1 class="view">Log <small>view</small></h1>
        <table id="list_logs" class="table table-bordered datatables"></table>
    </div>
{% endblock %}
