/* some bootstrap modifications */
body {
    padding-top: 60px;
    padding-bottom: 20px;
}

h1.view {
    margin-bottom: 15px;
}
h1.datatables-filter {
    margin-bottom: 15px;
}

/* background colors */
.error {
      background-color: lighten(#f56a66, 25%)!important;
      border-color: lighten(#f56a66, 20%)!important;
}
.ok {
      background-color: lighten(#62c462, 30%)!important;
      border-color: lighten(#62c462, 25%)!important;
}
.unknown {
      background-color: lighten(#6bd0ee, 25%)!important;
      border-color: lighten(#6bd0ee, 20%)!important;
}
.yellow {
      background-color: lighten(#FAA732, 25%)!important;
      border-color: lighten(#FAA732, 20%)!important;
}

/* console.pt */
#console {
    height: 400px;
    overflow-y: scroll;
}
#command {
    width: 100%;
}
#command-btn {
    width: 100%;
}

/* rows clickable */
.clickable-row {
    cursor: pointer;
}

/* don't word wrap size columns */
.nowrap {
    white-space: nowrap;
}

/* control width of the table with long words */
table.word-wrapped {
    table-layout: fixed;
}
table.word-wrapped tr td {
    word-wrap: break-word;
}

/* footer */
footer {
    text-align: center;
}
