{% extends "templates/base.jinja2" %}

{% block content %}
    <h1 class="view">Pool <small>{{ object.name }}</small></h1>

    <h2 class="view">Volumes <small>list</small></h2>
    {{ macros.volumes_table(request, object.medias) }}
{% endblock %}

{% block sidebar %}
    <h1 class="view">Details</h1>
    <table class="table table-striped table-bordered table-condensed word-wrapped">
        <tbody>
            <tr>
                <td>Name:</td>
                <td>{{ object.name }}</td>
            </tr>
            <tr>
                <td>Enabled:</td>
                <td>{{ macros.link(object.render_enabled(request)) }}</td>
            </tr>
            <tr>
                <td>Type:</td>
                <td>{{ object.pooltype }}</td>
            </tr>
            <tr>
                <td>Use catalog:</td>
                <td>{{ macros.link(object.render_usecatalog(request)) }}</td>
            </tr>
            <tr>
                <td>Use once:</td>
                <td>{{ macros.link(object.render_useonce(request)) }}</td>
            </tr>
            <tr>
                <td>Recycle:</td>
                <td>{{ macros.link(object.render_recycle(request)) }}</td>
            </tr>
            <tr>
                <td>Auto prune:</td>
                <td>{{ macros.link(object.render_autoprune(request)) }}</td>
            </tr>
            <tr>
                <td>Accepts any volume:</td>
                <td>{{ macros.link(object.render_acceptanyvolume(request)) }}</td>
            </tr>
            <tr>
                <td>Number of volumes:</td>
                <td>{{ object.numvols }}</td>
            </tr>
            <tr>
                <td>Maximum volumes:</td>
                <td>{{ object.maxvols }}</td>
            </tr>
            <tr>
                <td>Maximum volume jobs:</td>
                <td>{{ object.maxvoljobs }}</td>
            </tr>
            <tr>
                <td>Maximum volume files:</td>
                <td>{{ object.maxvolfiles }}</td>
            </tr>
            <tr>
                <td>Maximum volume size:</td>
                <td>{{ object.maxvolbytes }}</td>
            </tr>
            <tr>
                <td>Volume retention:</td>
                <td>{{ object.volretention }}</td>
            </tr>
            <tr>
                <td>Volume use duration:</td>
                <td>{{ object.voluseduration }}</td>
            </tr>
        </tbody>
    </table>
{% endblock %}
