{% extends "templates/base.jinja2" %}

{% block content %}
    <h1 class="view">Storage <small>{{ object.name }}</small></h1>

    <h1 class="view">Volumes <small>list</small></h1>
    {{ macros.volumes_table(request, object.medias) }}
{% endblock %}

{% block sidebar %}
    <h1 class="view">Details</h1>
    <table class="table table-striped table-bordered table-condensed word-wrapped">
        <tbody>
            <tr>
                <td>Name:</td>
                <td>{{ macros.link(object.render_name(request)) }}</td>
            </tr>
            <tr>
                <td>Autochanger:</td>
                <td>{{ macros.link(object.render_autochanger(request)) }}</td>
            </tr>
        </tbody>
    </table>
{% endblock %}
