{% extends "templates/base.jinja2" %}

{% block container %}
    <h1 class="view">Pools <small>list</small></h1>
    <table class="table table-striped table-bordered datatables">
        <thead>
            <tr>
                <th>Name</th>
                <th>Type</th>
                <th>Num of volumes</th>
            </tr>
        </thead>
        <tbody>
            {% for pool in objects %}
                <tr class="clickable-row" data-link="{{ request.route_url('pool_detail', id=pool.poolid) }}">
                   <td>{{ macros.link(pool.render_name(request)) }}</td>
                   <td>{{ pool.pooltype }}</td>
                   <td>{{ pool.numvols }}</td>
                </tr>
            {% endfor %}
        </tbody>
    </table>
{% endblock %}
