# generated by almir/scripts/parse_console_commands.py
CONSOLE_COMMANDS = {
    "add": {"desc": "Add media to a pool", "help": "pool=<pool-name> storage=<storage> jobid=<JobId>"},
    "autodisplay": {"desc": "Autodisplay console messages", "help": "on OR off"},
    "automount": {"desc": "Automount after label", "help": "on OR off"},
    "cancel": {"desc": "Cancel a job", "help": "jobid=<number> job=<job-name> ujobid=<unique-jobid>"},
    "create": {"desc": "Create DB Pool from resource", "help": "pool=<pool-name>"},
    "delete": {"desc": "Delete volume, pool or job", "help": "volume=<vol-name> pool=<pool-name> jobid=<id>"},
    "disable": {"desc": "Disable a job", "help": "job=<name>"},
    "enable": {"desc": "Enable a job", "help": "job=<name>"},
    "estimate": {"desc": "Performs FileSet estimate, listing gives full listing", "help": "fileset=<fs> client=<cli> level=<level> accurate=<yes/no> job=<job> listing"},
    "gui": {"desc": "Non-interactive gui mode", "help": "on OR off"},
    "help": {"desc": "Print help on specific command", "help": "add autodisplay automount cancel create delete disable\n\tenable estimate exit gui label list llist"
       "\n\tmessages memory mount prune purge python quit query\n\trestore relabel release reload run status"
       "\n\tsetdebug setip show sqlquery time trace unmount\n\tumount update use var version wait"},
    "label": {"desc": "Label a tape", "help": "storage=<storage> volume=<vol> pool=<pool> slot=<slot> barcodes"},
    "list": {"desc": "List objects from catalog", "help": "pools OR jobs OR jobtotals OR volume OR media <pool=pool-name> OR files jobid=<nn> OR copies jobid=<nn>"},
    "llist": {"desc": "Full or long list like list command", "help": "pools OR jobs OR jobtotals OR media <pool=pool-name> OR files jobid=<nn> OR copies jobid=<nn>"},
    "mount": {"desc": "Mount storage", "help": "storage=<storage-name> slot=<num> drive=<num> [ jobid=<id> OR job=<job-name> ]"},
    "prune": {"desc": "Prune expired records from catalog", "help": "files OR jobs OR pool=<pool> OR client=<client-name> OR volume=<volume-name> "},
    "purge": {"desc": "Purge records from catalog", "help": "files jobs volume=<vol> [action=<action> devicetype=<type> pool=<pool> allpools storage=<st> drive=<num>]"},
    "restore": {"desc": "Restore files", "help": "where=</path> client=<client> storage=<storage> bootstrap=<file> "
       "restore_job=<job>"
       "\n\tcomment=<text> jobid=<jobid> done select all"},
    "relabel": {"desc": "Relabel a tape", "help": "storage=<storage-name> oldvolume=<old-volume-name>\n\tvolume=<newvolume-name> pool=<pool>"},
    "release": {"desc": "Release storage", "help": "storage=<storage-name>"},
    "run": {"desc": "Run a job", "help": "job=<job-name> client=<client-name>\n\tfileset=<FileSet-name> level=<level-keyword>\n\tstorage=<storage-name>"
       "where=<directory-prefix>\n\twhen=<universal-time-specification>\n\tcomment=<text> yes"},
    "status": {"desc": "Report status", "help": "all OR dir=<dir-name> OR director OR client=<client-name> OR storage=<storage-name> slots OR days=nnn"},
    "setdebug": {"desc": "Sets debug level", "help": "level=<nn> trace=0/1 client=<client-name> OR dir OR storage=<storage-name> OR all"},
    "show": {"desc": "Show resource records", "help": "job=<xxx> OR  pool=<yyy> OR fileset=<aaa> schedule=<sss> OR client=<zzz> OR disabled OR all"},
    "trace": {"desc": "Turn on/off trace to file", "help": "on OR off"},
    "unmount": {"desc": "Unmount storage", "help": "storage=<storage-name> [ drive=<num> ] OR jobid=<id> OR job=<job-name>"},
    "umount": {"desc": "Umount - for old-time Unix guys, see unmount", "help": "storage=<storage-name> [ drive=<num> ] OR jobid=<id> OR job=<job-name>"},
    "update": {"desc": "Update volume, pool or stats", "help": "stats\n\tpool=<poolname>\n\tslots storage=<storage> scan"
       "\n\tvolume=<volname> volstatus=<status> volretention=<time-def>"
       "\n\t pool=<pool> recycle=<yes/no> slot=<number>\n\t inchanger=<yes/no>"
       "\n\t maxvolbytes=<size> maxvolfiles=<nb> maxvoljobs=<nb>"
       "\n\t enable=<yes/no> recyclepool=<pool> actiononpurge=<action>"},
    "use": {"desc": "Use catalog xxx", "help": "catalog=<catalog>"},
    "wait": {"desc": "Wait until no jobs are running", "help": "jobname=<name> OR jobid=<nnn> OR ujobid=<complete_name>"},
}
